﻿using System.Runtime.Serialization;
using JelleDruyts.Windows.ObjectModel;

namespace Schedulr.Models
{
    /// <summary>
    /// Contains all settings for an <see cref="Account"/>.
    /// </summary>
    [DataContract(Namespace = Constants.DataContractNamespace)]
    public class AccountSettings : ObservableObject
    {
        #region Observable Properties

        /// <summary>
        /// Gets or sets the default values for new pictures.
        /// </summary>
        [DataMember]
        public Picture PictureDefaults
        {
            get { return this.GetValue(PictureDefaultsProperty); }
            set { this.SetValue(PictureDefaultsProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="PictureDefaults"/> observable property.
        /// </summary>
        public static ObservableProperty<Picture> PictureDefaultsProperty = new ObservableProperty<Picture, AccountSettings>(o => o.PictureDefaults);

        /// <summary>
        /// Gets or sets a value that determines if picture metadata should be retrieved for new pictures.
        /// </summary>
        [DataMember]
        public bool RetrieveMetadata
        {
            get { return this.GetValue(RetrieveMetadataProperty); }
            set { this.SetValue(RetrieveMetadataProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="RetrieveMetadata"/> observable property.
        /// </summary>
        public static ObservableProperty<bool> RetrieveMetadataProperty = new ObservableProperty<bool, AccountSettings>(o => o.RetrieveMetadata, true);

        /// <summary>
        /// Gets or sets a value that determines if pictures should be deleted after they have been uploaded.
        /// </summary>
        [DataMember]
        public bool DeleteFileAfterUpload
        {
            get { return this.GetValue(DeleteFileAfterUploadProperty); }
            set { this.SetValue(DeleteFileAfterUploadProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="DeleteFileAfterUpload"/> observable property.
        /// </summary>
        public static ObservableProperty<bool> DeleteFileAfterUploadProperty = new ObservableProperty<bool, AccountSettings>(o => o.DeleteFileAfterUpload);

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="AccountSettings"/> class.
        /// </summary>
        public AccountSettings()
        {
            this.PictureDefaults = new Picture();
        }

        #endregion
    }
}