﻿using System.IO;
using Schedulr.Infrastructure;
using Schedulr.Models;

namespace Schedulr.ViewModels
{
    /// <summary>
    /// The view model for a picture in a picture list.
    /// </summary>
    public class PictureViewModel
    {
        /// <summary>
        /// Gets the picture.
        /// </summary>
        public Picture Picture { get; private set; }

        /// <summary>
        /// Gets the URL of the image to display in the list.
        /// </summary>
        public string ImageUrl { get; private set; }

        /// <summary>
        /// Gets a value that determines if the picture has errors.
        /// </summary>
        public bool HasErrors { get; set; }

        /// <summary>
        /// Initializes a new instance of the <see cref="PictureViewModel"/> class.
        /// </summary>
        /// <param name="picture">The picture.</param>
        /// <param name="account">The account.</param>
        public PictureViewModel(Picture picture, Account account)
        {
            this.Picture = picture;
            this.ImageUrl = picture.FileName;
            if (!string.IsNullOrWhiteSpace(this.Picture.PreviewUrl))
            {
                // There is an online preview URL (of the uploaded picture), check if the local file
                // still exists and if not use the online preview URL.
                if (!File.Exists(picture.FileName))
                {
                    this.ImageUrl = picture.PreviewUrl;
                }
            }
            this.HasErrors = !Validator.IsPictureValid(picture, account);
        }
    }
}