﻿using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using JelleDruyts.Windows.ObjectModel;

namespace Schedulr.Models
{
    /// <summary>
    /// Represents the configuration for Schedulr.
    /// </summary>
    [DataContract(Namespace = Constants.DataContractNamespace)]
    public class SchedulrConfiguration : ObservableObject
    {
        #region Observable Properties

        /// <summary>
        /// Gets or sets the configured accounts.
        /// </summary>
        [DataMember]
        public ObservableCollection<Account> Accounts
        {
            get { return this.GetValue(AccountsProperty); }
            set { this.SetValue(AccountsProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="Accounts"/> observable property.
        /// </summary>
        public static ObservableProperty<ObservableCollection<Account>> AccountsProperty = new ObservableProperty<ObservableCollection<Account>, SchedulrConfiguration>(o => o.Accounts);

        /// <summary>
        /// Gets or sets the UI settings.
        /// </summary>
        [DataMember]
        public UISettings UISettings
        {
            get { return this.GetValue(UISettingsProperty); }
            set { this.SetValue(UISettingsProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="UISettings"/> observable property.
        /// </summary>
        public static ObservableProperty<UISettings> UISettingsProperty = new ObservableProperty<UISettings, SchedulrConfiguration>(o => o.UISettings);

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="SchedulrConfiguration"/> class.
        /// </summary>
        public SchedulrConfiguration()
        {
            this.Accounts = new ObservableCollection<Account>();
            this.UISettings = new UISettings();
        }

        #endregion
    }
}