﻿using JelleDruyts.Windows.ObjectModel;

namespace Schedulr.Infrastructure
{
    public class BatchHeader : ObservableObject
    {
        #region Properties

        public int Id { get; private set; }

        #endregion

        #region Observable Properties

        /// <summary>
        /// Gets or sets the long name.
        /// </summary>
        public string LongName
        {
            get { return this.GetValue(LongNameProperty); }
            set { this.SetValue(LongNameProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="LongName"/> observable property.
        /// </summary>
        public static ObservableProperty<string> LongNameProperty = new ObservableProperty<string, BatchHeader>(o => o.LongName);

        /// <summary>
        /// Gets or sets the short name.
        /// </summary>
        public string ShortName
        {
            get { return this.GetValue(ShortNameProperty); }
            set { this.SetValue(ShortNameProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="ShortName"/> observable property.
        /// </summary>
        public static ObservableProperty<string> ShortNameProperty = new ObservableProperty<string, BatchHeader>(o => o.ShortName);

        /// <summary>
        /// Gets or sets a value that determines if the batch header is expanded.
        /// </summary>
        public bool IsExpanded
        {
            get { return this.GetValue(IsExpandedProperty); }
            set { this.SetValue(IsExpandedProperty, value); }
        }

        /// <summary>
        /// The definition for the <see cref="IsExpanded"/> observable property.
        /// </summary>
        public static ObservableProperty<bool> IsExpandedProperty = new ObservableProperty<bool, BatchHeader>(o => o.IsExpanded);

        #endregion

        #region Constructors

        public BatchHeader(int id, string longName, string shortName, bool isExpanded)
        {
            this.Id = id;
            this.LongName = longName;
            this.ShortName = shortName;
            this.IsExpanded = isExpanded;
        }

        #endregion

        #region ToString, Equals, GetHashCode

        public override string ToString()
        {
            return this.LongName;
        }

        public override bool Equals(object obj)
        {
            var other = obj as BatchHeader;
            if (obj == null)
            {
                return false;
            }
            return this.Id == other.Id;
        }

        public override int GetHashCode()
        {
            return this.Id;
        }

        #endregion
    }
}