﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows.Input;
using JelleDruyts.Windows;
using Schedulr.Messages;
using Schedulr.Models;

namespace Schedulr.ViewModels
{
    public class UploadedPicturesViewModel : PictureListViewModel
    {
        protected override ObservableCollection<Picture> GetPicturesForAccount(Account account)
        {
            return account.UploadedPictures;
        }

        protected override PictureDetailsUISettings GetUISettingsForAccount(Account account)
        {
            return account.Settings.UploadedPictureDetailsUISettings;
        }

        protected override bool IsDragDropSupportedOnQueue
        {
            get { return false; }
        }

        protected override IEnumerable<ICommand> GetQueueCommands()
        {
            return new RelayCommand[]
            {
                new RelayCommand(this.Enqueue, this.CanEnqueue, "En_queue", "Adds the selected files back to the upload queue, each in its own batch [INS]", new KeyGesture(Key.Insert)),
                new RelayCommand(this.EnqueueBatch, this.CanEnqueueBatch, "Enqueue _Batch", "Adds the selected files back to the upload queue, all in the same batch [ALT-INS]", new KeyGesture(Key.Insert, ModifierKeys.Alt)),
                this.ExpandAllBatchesCommand,
                this.CollapseAllBatchesCommand,
                this.RemoveCommand
            };
        }

        protected override bool ArePictureDetailsReadOnly
        {
            get { return true; }
        }

        #region Commands

        private bool CanEnqueue(object parameter)
        {
            return (this.SelectedPictures.Count > 0);
        }

        private void Enqueue(object parameter)
        {
            Enqueue(false);
        }

        private bool CanEnqueueBatch(object parameter)
        {
            return (this.SelectedPictures.Count > 1);
        }

        private void EnqueueBatch(object parameter)
        {
            Enqueue(true);
        }

        private void Enqueue(bool addToSingleBatch)
        {
            var pictures = new List<Picture>();
            foreach (var selectedPicture in this.SelectedPictures)
            {
                var clone = SerializationProvider.Clone<Picture>(selectedPicture);
                clone.DateUploaded = null;
                clone.BatchId = 0;
                clone.PictureId = null;
                clone.PreviewUrl = null;
                clone.WebUrl = null;
                pictures.Add(clone);
            }
            Messenger.Send<AddPicturesRequestedMessage>(new AddPicturesRequestedMessage(pictures, addToSingleBatch));
        }

        #endregion
    }
}